@@ -145,7 +145,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_UNKNOWN;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -154,7 +154,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_UNDEF;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -163,7 +163,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_VOID;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -172,7 +172,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_BYTE;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -181,7 +181,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_SHORT;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -190,7 +190,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_INT;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -199,7 +199,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_LONG;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -208,7 +208,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_FLOAT;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -217,7 +217,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_DOUBLE;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -226,7 +226,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_STRING;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -235,7 +235,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_ANY_OBJECT;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -244,7 +244,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_OARRAY;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -253,7 +253,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_BYTE_OBJECT;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -262,7 +262,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_SHORT_OBJECT;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -271,7 +271,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_INT_OBJECT;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -280,7 +280,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_LONG_OBJECT;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -289,7 +289,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_FLOAT_OBJECT;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
@@ -298,7 +298,7 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_DOUBLE_OBJECT;
-     basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
+     basic_type->name = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
   }
